@@ -634,16 +634,16 @@ static int min_bugfix = 0;
 
 static int cyclone_major = 0;
 static int cyclone_minor = 9;
-static int cyclone_bugfix = 0;
+static int cyclone_bugfix = 3;
 
 void print_cyclone(t_cyclone *x){
     int major = 0, minor = 0, bugfix = 0;
     sys_getversion(&major, &minor, &bugfix);
     post("");
     post("--------------------------------------------------------------------");
-    post(":: Cyclone %d.%d-%d; Released July 2nd 2024", cyclone_major, cyclone_minor, cyclone_bugfix);
+    post(":: Cyclone %d.%d-%d; Released May 16th 2025", cyclone_major, cyclone_minor, cyclone_bugfix);
     post(":: License: BSD-3-Clause (aka Revised BSD License)");
-    post(":: Copyright © 2003-2024 - Krzysztof Czaja, Hans-Christoph Steiner,");
+    post(":: Copyright © 2003-2025 - Krzysztof Czaja, Hans-Christoph Steiner,");
     post(":: Fred Jan Kraan, Alexandre Porres, Derek Kwan, Matt Barber\n\:: and others.");
     post(":: -----------------------------------------------------------------");
     if((major > min_major)
